/* GNOME-DB Components
 * Copyright (C) 2000-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#if !defined(__database_capplet_h__)
#  define __database_capplet_h__

#include <gtk/gtkwidget.h>

#define DSN_PAGE      "DSN_Page"
#define PROVIDER_PAGE "Provider_Page"

GtkWidget *database_capplet_new (void);
void       database_capplet_edit_properties (GtkWidget *capplet);
void       database_capplet_delete (GtkWidget *capplet);
void       database_capplet_select_all (GtkWidget *capplet);
void       database_capplet_deselect_all (GtkWidget *capplet);
gboolean   database_capplet_has_selection (GtkWidget *capplet);
void       database_capplet_switch (GtkWidget *capplet, const gchar *page);

#endif
